SignupData class

Constructors

SignupData.fromProvider({required Map<String, String>? additionalSignupData, List<TermOfServiceResult> termsOfService = const []})
SignupData.fromSignupForm({required String? name, required String? password, Map<String, String>? additionalSignupData, List<TermOfServiceResult> termsOfService = const []})

Properties

additionalSignupData → Map<String, String>?
final
hashCode → int
The hash code for this object.
no setteroverride
name → String?
final
password → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
termsOfService → List<TermOfServiceResult>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override